#[repr(transparent)]pub struct Stat(pub u32);Expand description
Status register.
Tuple Fields
0: u32Implementations
Sourceimpl Stat
impl Stat
Sourcepub const fn intr(&self) -> bool
pub const fn intr(&self) -> bool
Interrupt flag. 0 = No interrupt is pending. 1 = An interrupt is pending. A write of any value to this register clears this flag.
Sourcepub const fn set_intr(&mut self, val: bool)
pub const fn set_intr(&mut self, val: bool)
Interrupt flag. 0 = No interrupt is pending. 1 = An interrupt is pending. A write of any value to this register clears this flag.
Sourcepub const fn active(&self) -> bool
pub const fn active(&self) -> bool
Active flag. 0 = The Micro-Tick Timer is stopped. 1 = The Micro-Tick Timer is currently active.
Sourcepub const fn set_active(&mut self, val: bool)
pub const fn set_active(&mut self, val: bool)
Active flag. 0 = The Micro-Tick Timer is stopped. 1 = The Micro-Tick Timer is currently active.